@@ -19,7 +19,7 @@ void update_z_t( int z[], int n_i[], int *df_t,
 			double mu_c[], double sig_c[], double pi_c[] 
 			)
 {
-	GetRNGstate();
+	//GetRNGstate();
 	vector<double> prob_z( *k_c ); 
 	// Sample group memberships from multinominal distribution
 	// for( j in 1:n ) z[, j] = rmultinom( n = 1, size = 1, prob = pi * dnorm( data[j], mean = mu, sd = sqrt( sig ) ) )	
@@ -47,14 +47,14 @@ void update_z_t( int z[], int n_i[], int *df_t,
 			sum_n += z[ j * *k_c + i ];
 		n_i[i] = sum_n;
 	}
-	PutRNGstate();
+	//PutRNGstate();
 }	
     
 // update q_j
 void update_q_t( double q_t[], double data_c[], int z[], int *df_t, int *n_c, int *k_c, 
 			double mu_c[], double sig_c[] )
 {
-	GetRNGstate();
+	//GetRNGstate();
 	for( int j = 0; j < *n_c; j++ )
 	{
 		// df_post = df_post + z[i,j] * ( ( ( data[j] - mu[i] ) ^ 2 ) / sig[i] )
@@ -64,7 +64,7 @@ void update_q_t( double q_t[], double data_c[], int z[], int *df_t, int *n_c, in
 		
 		q_t[j] = rgamma( ( *df_t + 1.0 ) / 2.0, 2.0 / ( *df_t + df_post ) );
 	}	
-	PutRNGstate();
+	//PutRNGstate();
 }
 
 // update beta
@@ -74,20 +74,20 @@ void update_beta_t(
 			double sig_c[] 
 			)
 {
-	GetRNGstate();
+	//GetRNGstate();
 	// beta_r = rgamma( 1, g + k * alpha, h + sum( 1 / sig ) )
 	double sum_inv_sig = 0.0;
 	for( int i = 0; i < *k_c; i++ ) 
 		sum_inv_sig += 1.0 / sig_c[i];
 	
 	*beta_new = rgamma( *g_c + *k_c * *alpha_c, 1.0 / ( *h_c + sum_inv_sig ) );	
-	PutRNGstate();
+	//PutRNGstate();
 }
     
 // update pi : Sample mixtures proportions (pi) from a dirichlet distribution
 void update_pi_t( double pi_c[], int n_i[], int *n_c, int *k_c )
 {
-	GetRNGstate();
+	//GetRNGstate();
 	// for( i in 1:k ) pi[i] = rgamma( n = 1, shape = 1 + n_i[i], scale = 1 ) 
 	for( int i = 0; i < *k_c; i++ ) 
 		pi_c[i] = rgamma( 1 + n_i[i], 1 ); 
@@ -97,7 +97,7 @@ void update_pi_t( double pi_c[], int n_i[], int *n_c, int *k_c )
 	double sum_pi = 0.0;
 	for( int i = 0; i < *k_c; i++ ) sum_pi  += pi_c[i];
 	for( int i = 0; i < *k_c; i++ ) pi_c[i] /= sum_pi;
-	PutRNGstate();
+	//PutRNGstate();
 }
     
 // update mu
@@ -107,7 +107,7 @@ void update_mu_t( double q_t[],
 			double mu_c[], double sig_c[] 
 			)
 {
-	GetRNGstate();
+	//GetRNGstate();
 	for( int i = 0; i < *k_c; i++ ) 
 	{
 		// Set mixture sample mean
@@ -131,7 +131,7 @@ void update_mu_t( double q_t[],
 		// Sample new mean from normal distribution
 		mu_c[i] = rnorm( mu_mean, sqrt( mu_sig ) );
 	}
-	PutRNGstate();
+	//PutRNGstate();
 }
     
 // update sig
@@ -141,7 +141,7 @@ void update_sig_t( double *beta_new, double q_t[],
 			double mu_c[], double sig_c[] 
 			)
 {
-	GetRNGstate();
+	//GetRNGstate();
 	for( int i = 0; i < *k_c; i++ ) 
 	{
 		// Set inverse gamma posterior parameters
@@ -163,7 +163,7 @@ void update_sig_t( double *beta_new, double q_t[],
 		// sig[i] = 1 / rgamma( n = 1, alpha_sig, beta_sig )
 		sig_c[i] = 1.0 / rgamma( alpha_sig, 1.0 / beta_sig );
 	}	
-	PutRNGstate();
+	//PutRNGstate();
 }
     
 // update all the parameters
@@ -233,6 +233,7 @@ void bmix_t_unknown_k( double data_r[], int *n, int *k, int *k_max_r, int *iter,
 						double mu[], double sig[], double pi_r[], 
 						double q_t_r[], int *df_t_r )
 {
+	GetRNGstate();
 	int n_c = *n, k_c = *k, iteration = *iter, burn_in = *burnin, sweep = iteration - burn_in;
 	int i, j, ij;
 	int df_t = *df_t_r;
@@ -257,7 +258,6 @@ void bmix_t_unknown_k( double data_r[], int *n, int *k, int *k_max_r, int *iter,
 	double max_numeric_limits_ld = numeric_limits<double>::max() / 10000;
 	double min_numeric_limits_ld = numeric_limits<double>::min() * 10000;
 	
-	GetRNGstate();
 	// main loop for birth-death MCMC sampling algorithm ----------------------| 
 	for( int i_mcmc = 0; i_mcmc < iteration; i_mcmc++ )
 	{
@@ -400,6 +400,7 @@ void bmix_t_fixed_k(
 			double mu[], double sig[], double pi_r[], 
 			double q_t_r[], int *df_t_r )
 {
+	GetRNGstate();
 	int n_c = *n, k_c = *k, iteration = *iter, burn_in = *burnin, sweep = iteration - burn_in;
 	int i, ij;
 	int df_t = *df_t_r;
@@ -421,7 +422,6 @@ void bmix_t_fixed_k(
 		
 	int counter = 0;
 
-	GetRNGstate();
 	// main loop for birth-death MCMC sampling algorithm ----------------------| 
 	for( int i_mcmc = 0; i_mcmc < iteration; i_mcmc++ )
 	{
